@@ -16,7 +16,7 @@ use GD::Polygon;
 
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $AUTOLOAD);
 
-$VERSION = '2.72';
+$VERSION = '2.74';
 our $XS_VERSION = $VERSION;
 $VERSION = eval $VERSION;
 
@@ -128,7 +128,7 @@ GD.pm - Interface to Gd Graphics Library
     use GD;
 
     # create a new image
-    $im = new GD::Image(100,100);
+    $im = GD::Image->new(100,100);
 
     # allocate some colors
     $white = $im->colorAllocate(255,255,255);
@@ -199,7 +199,7 @@ A Simple Example:
 	use GD;
 
 	# create a new image
-	$im = new GD::Image(100,100);
+	$im = GD::Image->new(100,100);
 
 	# allocate some colors
 	$white = $im->colorAllocate(255,255,255);
@@ -266,6 +266,8 @@ the image to.
 
 =head1 Object Constructors: Creating Images
 
+See L<GD::Image> for the current list of supported Image formats.
+
 The following class methods allow you to create new GD::Image objects.
 
 =over 4
@@ -282,7 +284,7 @@ The new() method is the main constructor for the GD::Image class.
 Called with two integer arguments, it creates a new blank image of the
 specified width and height. For example:
 
-	$myImage = new GD::Image(100,100) || die;
+	$myImage = GD::Image->new(100,100) || die;
 
 This will create an image that is 100 x 100 pixels wide.  If you don't
 specify the dimensions, a default of 64 x 64 will be chosen.
@@ -297,7 +299,7 @@ compatibility with older versions of libgd.
 Alternatively, you may create a GD::Image object based on an existing
 image by providing an open filehandle, a filename, or the image data
 itself.  The image formats automatically recognized and accepted are:
-PNG, JPEG, XPM and GD2.  Other formats, including WBMP, and GD
+GIF, PNG, JPEG, XPM, GD2 and WEBP.  Other formats, including WBMP, and GD
 version 1, cannot be recognized automatically at this time.
 
 If something goes wrong (e.g. insufficient memory), this call will
@@ -352,11 +354,11 @@ and read the PNG information from it.
   Example1:
 
   open (PNG,"barnswallow.png") || die;
-  $myImage = newFromPng GD::Image(\*PNG) || die;
+  $myImage = GD::Image->newFromPng(\*PNG) || die;
   close PNG;
 
   Example2:
-  $myImage = newFromPng GD::Image('barnswallow.png');
+  $myImage = GD::Image->newFromPng('barnswallow.png');
 
 To get information about the size and color usage of the information,
 you can call the image query methods described below. Images created
@@ -397,7 +399,7 @@ This works in exactly the same way as C<newFromPng>, but reads the
 contents of an X Bitmap (black & white) file:
 
 	open (XBM,"coredump.xbm") || die;
-	$myImage = newFromXbm GD::Image(\*XBM) || die;
+	$myImage = GD::Image->newFromXbm(\*XBM) || die;
 	close XBM;
 
 There is no newFromXbmData() function, because there is no
@@ -409,7 +411,7 @@ This works in exactly the same way as C<newFromPng>, but reads the
 contents of an Windows BMP Bitmap file:
 
 	open (BMP,"coredump.bmp") || die;
-	$myImage = newFromWBMP GD::Image(\*BMP) || die;
+	$myImage = GD::Image->newFromWBMP(\*BMP) || die;
 	close BMP;
 
 There is no newFromWBMPData() function, because there is no
@@ -419,19 +421,23 @@ corresponding function in the gd library.
 
 =item B<$image = GD::Image-E<gt>newFromGdData($data)>
 
+NOTE: GD and GD2 support was dropped witn libgd 2.3.2.
+
 These methods initialize a GD::Image from a Gd file, filehandle, or
 data.  Gd is Tom Boutell's disk-based storage format, intended for the
 rare case when you need to read and write the image to disk quickly.
 It's not intended for regular use, because, unlike PNG or JPEG, no
 image compression is performed and these files can become B<BIG>.
 
-	$myImage = newFromGd GD::Image("godzilla.gd") || die;
+	$myImage = GD::Image->newFromGd("godzilla.gd") || die;
 	close GDF;
 
 =item B<$image = GD::Image-E<gt>newFromGd2($file)>
 
 =item B<$image = GD::Image-E<gt>newFromGd2Data($data)>
 
+NOTE: GD and GD2 support was dropped witn libgd 2.3.2.
+
 This works in exactly the same way as C<newFromGd()> and
 newFromGdData, but use the new compressed GD2 image format.
 
@@ -456,7 +462,7 @@ is unlike the other newFrom() functions because it does not take a
 filehandle.  This difference comes from an inconsistency in the
 underlying gd library.
 
-	$myImage = newFromXpm GD::Image('earth.xpm') || die;
+	$myImage = GD::Image->newFromXpm('earth.xpm') || die;
 
 This function is only available if libgd was compiled with XPM
 support.  
@@ -483,9 +489,12 @@ following extensions are supported:
     .jpg, .jpeg
     .tiff, .tif
     .webp
+    .heic, .heix
+    .avif
     .xpm
 
 Filenames are parsed case-insensitively.
+.avifs is not yet suppurted upstream in libavif.
 
 =back
 
@@ -625,6 +634,9 @@ use sane defaults:
   C<gdImageGd2>	chunk size = 0, compression is enabled.
   C<gdImageJpeg>	quality = -1 (i.e. the reasonable default)
   C<gdImageWBMP>	foreground is the darkest available color
+  C<gdImageWEBP>	quality default
+  C<gdImageHEIF>	quality default, codes = HEVC, chroma = 444
+  C<gdImageAVIF>	quality default, speed = 6
 
 Everything else is called with the two-argument function and so will
 use the default values.
@@ -804,7 +816,7 @@ current index of the transparent color, or -1 if none.
 Example:
 
 	open(PNG,"test.png");
-	$im = newFromPng GD::Image(PNG);
+	$im = GD::Image->newFromPng(PNG);
 	$white = $im->colorClosest(255,255,255); # find white
 	$im->transparent($white);
 	binmode STDOUT;
@@ -837,7 +849,7 @@ non-colored parts don't overwrite other parts of your image.
 Example:
 
 	# Create a brush at an angle
-	$diagonal_brush = new GD::Image(5,5);
+	$diagonal_brush = GD::Image->new(5,5);
 	$white = $diagonal_brush->colorAllocate(255,255,255);
 	$black = $diagonal_brush->colorAllocate(0,0,0);
 	$diagonal_brush->transparent($white);
@@ -1011,7 +1023,7 @@ with a pattern.
 Example:
 
 	# read in a fill pattern and set it
-	$tile = newFromPng GD::Image('happyface.png');
+	$tile = GD::Image->newFromPng('happyface.png');
 	$myImage->setTile($tile); 
 
 	# draw the rectangle, filling it with the pattern
@@ -1027,7 +1039,7 @@ colors gdBrushed, gdStyled and gdStyledBrushed can be specified.
 
 Example:
 
-	$poly = new GD::Polygon;
+	$poly = GD::Polygon->new;
 	$poly->addPt(50,0);
 	$poly->addPt(99,99);
 	$poly->addPt(0,99);
@@ -1045,7 +1057,7 @@ You need libgd 2.0.33 or higher to use this feature.
 
 Example:
 
-	$poly = new GD::Polygon;
+	$poly = GD::Polygon->new;
 	$poly->addPt(50,0);
 	$poly->addPt(99,99);
 	$poly->addPt(0,99);
@@ -1060,7 +1072,7 @@ with a pattern.
 Example:
 
 	# make a polygon
-	$poly = new GD::Polygon;
+	$poly = GD::Polygon->new;
 	$poly->addPt(50,0);
 	$poly->addPt(99,99);
 	$poly->addPt(0,99);
@@ -1180,9 +1192,9 @@ destination regions must not overlap or strange things will happen.
 
 Example:
 
-	$myImage = new GD::Image(100,100);
+	$myImage = GD::Image->new(100,100);
 	... various drawing stuff ...
-	$srcImage = new GD::Image(50,50);
+	$srcImage = GD::Image->new(50,50);
 	... more drawing stuff ...
 	# copy a 25x25 pixel region from $srcImage to
 	# the rectangle starting at (10,10) in $myImage
@@ -1196,7 +1208,7 @@ palette and other nonessential details.
 
 Example:
 
-	$myImage = new GD::Image(100,100);
+	$myImage = GD::Image->new(100,100);
 	... various drawing stuff ...
         $copy = $myImage->clone;
 
@@ -1213,9 +1225,9 @@ solid rectangle.
 
 Example:
 
-	$myImage = new GD::Image(100,100);
+	$myImage = GD::Image->new(100,100);
 	... various drawing stuff ...
-	$redImage = new GD::Image(50,50);
+	$redImage = GD::Image->new(50,50);
 	... more drawing stuff ...
 	# copy a 25x25 pixel region from $srcImage to
 	# the rectangle starting at (10,10) in $myImage, merging 50%
@@ -1241,9 +1253,9 @@ image to accommodate the size requirements.
 
 Example:
 
-	$myImage = new GD::Image(100,100);
+	$myImage = GD::Image->new(100,100);
 	... various drawing stuff ...
-	$srcImage = new GD::Image(50,50);
+	$srcImage = GD::Image->new(50,50);
 	... more drawing stuff ...
 	# copy a 25x25 pixel region from $srcImage to
 	# a larger rectangle starting at (10,10) in $myImage
@@ -1825,7 +1837,7 @@ Quickdraw library).  Also see L<GD::Polyline>.
 
 Create an empty polygon with no vertices.
 
-	$poly = new GD::Polygon;
+	$poly = GD::Polygon->new;
 
 =item B<$poly-E<gt>addPt($x,$y)>
 
@@ -1914,19 +1926,35 @@ box as the source rectangle.
 	# Make the polygon really tall
 	$poly->map($poly->bounds,0,0,50,200);
 
-=item B<$poly-E<gt>scale($sx,$sy)>
+=item B<$poly-E<gt>scale($sx,$sy, [$tx,$ty])>
 
 Scale each vertex of the polygon by the X and Y factors indicated by
 sx and sy.  For example scale(2,2) will make the polygon twice as
 large.  For best results, move the center of the polygon to position
 (0,0) before you scale, then move it back to its previous position.
+Accepts an optional offset vector.
 
-=item B<$poly-E<gt>transform($sx,$rx,$sy,$ry,$tx,$ty)>
+=item B<$poly-E<gt>transform($sx,$rx,$ry,$sy, $tx,$ty)>
 
-Run each vertex of the polygon through a transformation matrix, where
-sx and sy are the X and Y scaling factors, rx and ry are the X and Y
-rotation factors, and tx and ty are X and Y offsets.  See the Adobe
-PostScript Reference, page 154 for a full explanation, or experiment.
+Run each vertex of the polygon through a 2D affine transformation
+matrix, where sx and sy are the X and Y scaling factors, rx and ry are
+the X and Y rotation factors, and tx and ty are X and Y offsets.  See
+the Adobe PostScript Reference, page 154 for a full explanation, or
+experiment.
+
+libgd:
+
+    The transformation matrix is created using 6 numbers:
+    matrix[0] == xx
+    matrix[1] == yx
+    matrix[2] == xy
+    matrix[3] == xy (probably meaning yy here)
+    matrix[4] == x0
+    matrix[5] == y0
+    where the transformation of a given point (x,y) is given by:
+
+    x_new = xx * x + xy * y + x0;
+    y_new = yx * x + yy * y + y0;
 
 =back
 
